import { intersection, uniq } from 'lodash';
import React from 'react';
import { useDispatch, useSelector } from 'react-redux';

import { checkUserAuth } from '../redux/slices/authSlice';

const useAuth = (caps, { matchAllCaps = false }) => {
  const dispatch = useDispatch();
  const [isAuthorized, setIsAuthorized] = React.useState(false);

  const { isAuthenticated, userCapabilities } = useSelector((state) => ({
    isAuthenticated: state.authReducer.isAuthenticated,
    userCapabilities: state.authReducer.userCapabilities,
  }));

  const requiredCaps = React.useMemo(
    () => uniq(Array.isArray(caps) ? caps : [caps]),
    [caps]
  );

  React.useEffect(() => {
    const userMatchedCaps = intersection(userCapabilities, requiredCaps);

    let isUserAuthorized = matchAllCaps
      ? userMatchedCaps?.length === requiredCaps?.length
      : userMatchedCaps?.length > 0;
    if (requiredCaps.length === 0) {
      isUserAuthorized = true;
    }
    // if (isAuthenticated === null) {
      if (isAuthenticated === null || false || undefined) {
      dispatch(checkUserAuth());
    } else {
      setIsAuthorized(isAuthenticated && isUserAuthorized);
    }
  }, [dispatch, isAuthenticated, requiredCaps, userCapabilities]);

  return { isAuthenticated, isAuthorized };
};

export default useAuth;
